@@ -58,7 +58,7 @@
 #' \item target_trait: aggressiveness components (IR, LAT, IP, or PR) targeted by resistance genes,
 #' \item efficiency: resistance gene efficiencies (percentage of reduction of targeted aggressiveness components: 
 #' IR, 1/LAT, IP and PR),
-#' \item time_to_activ_exp: expected delays to resistance activation (for APRs),
+#' \item time_to_activ_mean: expected delays to resistance activation (for APRs),
 #' \item time_to_activ_var: variances of the delay to resistance activation (for APRs),
 #' \item mutation_prob: mutation probabilities for pathogenicity genes (each of them corresponding to a resistance gene),
 #' \item Nlevels_aggressiveness: number of adaptation levels related to each resistance gene (i.e. 1 + number
@@ -67,30 +67,45 @@
 #' to the considered resistance genes on host that do not carry the resistance genes,
 #' \item tradeoff_strength: strengths of the trade-off relationships between the level of aggressiveness
 #' on hosts that do and do not carry the resistance genes.
+#' \item recombination_sd: standard deviation of the normal distribution used for recombination of quantitative traits during sexual reproduction (infinitesimal model)
 #' }
 #' @param landscape a sp object containing the landscape (required only if videoMP4=TRUE).
 #' @param area a vector containing polygon areas (must be in square meters).
 #' @param rotation a dataframe containing for each field (rows) and year (columns, named "year_1", "year_2", etc.),
 #' the index of the cultivated croptype. Importantly, the matrix must contain 1 more column than the real number
 #' of simulated years.
-#' @param basic_patho_param a list of pathogen aggressiveness parameters on a susceptible host
-#' for a pathogen genotype not adapted to resistance: \itemize{
+#' @param basic_patho_param a list of i. pathogen aggressiveness parameters on a susceptible host
+#' for a pathogen genotype not adapted to resistance and ii. sexual reproduction parameters: \itemize{
 #' \item infection_rate = maximal expected infection rate of a propagule on a healthy host,
 #' \item propagule_prod_rate = maximal expected effective propagule production rate of an infectious host per time step,
-#' \item latent_period_exp = minimal expected duration of the latent period,
+#' \item latent_period_mean = minimal expected duration of the latent period,
 #' \item latent_period_var = variance of the latent period duration,
-#' \item infectious_period_exp = maximal expected duration of the infectious period,
+#' \item infectious_period_mean = maximal expected duration of the infectious period,
 #' \item infectious_period_var = variance of the infectious period duration,
 #' \item survival_prob = probability for a propagule to survive the off-season,
 #' \item repro_sex_prob = probability for an infectious host to reproduce via sex rather than via cloning,
 #' \item sigmoid_kappa = kappa parameter of the sigmoid contamination function,
 #' \item sigmoid_sigma = sigma parameter of the sigmoid contamination function,
-#' \item sigmoid_plateau = plateau parameter of the sigmoid contamination function.
+#' \item sigmoid_plateau = plateau parameter of the sigmoid contamination function,
+#' \item sex_propagule_viability_limit = maximum number of cropping seasons up to which a sexual propagule is viable
+#' \item sex_propagule_release_mean = average number of seasons after which a sexual propagule is released,
+#' \item clonal_propagule_gradual_release = Whether or not clonal propagules surviving the bottleneck are gradually released along the following cropping season.
 #' }
+#' @param repro_sex_prob a vector of size \code{time_param$nSTpY+1} of probability for an infectious host to reproduce
+#'  via sex rather than via cloning,
 #' @param disp_patho a vectorized matrix giving the probability of pathogen dispersal
 #' from any field of the landscape to any other field.
+#' @param disp_patho_sex a vectorized matrix giving the probability of dispersal for sexual pathogen propagules
+#' from any field of the landscape to any other field.
 #' @param disp_host a vectorized matrix giving the probability of host dispersal
 #' from any field of the landscape to any other field
+#' @param treatment list of parameters related to pesticide treatments: \itemize{ 
+#' \item treatment_reduction_rate = reduction per time step of chemical concentration,
+#' \item treatment_efficiency = maximal efficiency of chemical treatments (i.e. fractional reduction of pathogen infection rate at the application date),
+#' \item treatment_timesteps = vector of time-steps corresponding to treatment application dates,
+#' \item treatment_cultivars = vector of cultivar indices that receive treatments,
+#' \item treatment_cost = cost of a single treatment application (monetary units/ha)
+#' }
 #' @param pI0 initial probability for the first host (whose index is 0) to be infectious (i.e. state I)
 #' at the beginning of the simulation. Must be between 0 and 1.
 #' @param epid_outputs a character string (or a vector of character strings if several outputs are to be computed)
@@ -125,7 +140,6 @@
 #' @param thres_breakdown an integer (or vector of integers) giving the threshold (i.e. number of infections)
 #' above which a pathogen genotype is unlikely to go extinct, used to characterise the time to invasion
 #' of resistant hosts (several values are computed if several thresholds are given in a vector).
-#' @param GLAnoDis the absolute Green Leaf Area in absence of disease (used to compute economic outputs).
 #' @param audpc100S the audpc in a fully susceptible landscape (used as reference value for graphics).
 #' @param writeTXT a logical indicating if outputs must be written in text files (TRUE, default) or not (FALSE).
 #' @param graphic a logical indicating if graphics must be generated (TRUE, default) or not (FALSE).
@@ -137,9 +151,11 @@
 #' Briefly, the model is stochastic, spatially explicit (the basic spatial unit is an individual field), based on a SEIR
 #'  (‘susceptible-exposed-infectious-removed’, renamed HLIR for 'healthy-latent-infectious-removed' to avoid confusions
 #'  with 'susceptible host') structure with a discrete time step. It simulates the spread and
-#'  evolution of a pathogen in a heterogeneous cropping landscape, across cropping seasons split by host harvests which impose
-#'  potential bottlenecks to the pathogen. A wide array of resistance deployment strategies can be simulated and
-#'  evaluated using several possible outputs to assess the epidemiological, evolutionary and economic performance
+#'  evolution (via mutation, recombination through sexual reproduction, selection and drift) 
+#'  of a pathogen in a heterogeneous cropping landscape, across cropping seasons split by host harvests which impose
+#'  potential bottlenecks to the pathogen. A wide array of resistance deployment strategies 
+#'  (possibly including chemical treatments) can be simulated and evaluated using several possible 
+#'  outputs to assess the epidemiological, evolutionary and economic performance
 #'  of deployment strategies (See ?epid_output and ?evol_output for details).
 #'
 #' @return A list containing all outputs that have been required via "epid_outputs" and "evol_outputs".
@@ -181,7 +197,11 @@
 #'   seed = 12345, time_param, croptype_names, croptypes_cultivars_prop, cultivars,
 #'   cultivars_genes_list, genes, landscape = NULL, area, rotation,
 #'   basic_patho_param = loadPathogen(disease = "rust"),
-#'   disp_patho = c(0.99, 0.01, 0.01, 0.99), disp_host = c(1, 0, 0, 1), pI0 = 5e-4
+#'   repro_sex_prob = rep(0, time_param$nSTpY),
+#'   disp_patho = c(0.99, 0.01, 0.01, 0.99),
+#'   disp_patho_sex = c(0.99, 0.01, 0.01, 0.99),
+#'   disp_host = c(1, 0, 0, 1),
+#'   pI0 = 5e-4
 #' )
 #'
 #'
@@ -226,7 +246,9 @@
 #'   croptype_names, croptypes_cultivars_prop, cultivars,
 #'   cultivars_genes_list, genes, landscape, area, rotation,
 #'   basic_patho_param = loadPathogen(disease = "rust"),
+#'   repro_sex_prob = rep(0, 120+1),
 #'   disp_patho = loadDispersalPathogen(1),
+#'   disp_patho_sex = as.numeric(diag(Npoly)),
 #'   disp_host = as.numeric(diag(Npoly)),
 #'   pI0 = 5e-4
 #' )
@@ -239,71 +261,68 @@
 #' @export
 simul_landsepi <- function(seed = 12345, time_param = list(Nyears = 20, nTSpY = 120),
                            croptype_names, croptypes_cultivars_prop, cultivars, cultivars_genes_list,
-                           genes, landscape = NULL, area,
-                           rotation, basic_patho_param, disp_patho, disp_host, pI0 = 5e-4,
+                           genes, landscape = NULL, area, rotation, basic_patho_param, repro_sex_prob, 
+                           disp_patho, disp_patho_sex, disp_host, treatment, pI0 = 5e-4,
                            epid_outputs = "all", evol_outputs = "all", thres_breakdown = 50000,
-                           GLAnoDis = 1.48315, audpc100S = 0.76, #0.38,
+                           audpc100S = 0.76, #8.48 for downy mildew,
                            writeTXT = TRUE, graphic = TRUE, videoMP4 = FALSE, keepRawResults = FALSE) {
 
   # Host parameters
-  cultivars_param <- list(
-    name = as.character(cultivars$cultivarName),
-    initial_density = as.numeric(cultivars$initial_density),
-    max_density = as.numeric(cultivars$max_density),
-    growth_rate = as.numeric(cultivars$growth_rate),
-    reproduction_rate = as.numeric(cultivars$reproduction_rate),
-    death_rate = as.numeric(cultivars$death_rate),
-    sigmoid_kappa_host = 0,
-    sigmoid_sigma_host = 1,
-    sigmoid_plateau_host = 1,
-    cultivars_genes_list = cultivars_genes_list
+  cultivars_param <- list(name = as.character(cultivars$cultivarName),
+                          initial_density = as.numeric(cultivars$initial_density),
+                          max_density = as.numeric(cultivars$max_density),
+                          growth_rate = as.numeric(cultivars$growth_rate),
+                          reproduction_rate = as.numeric(cultivars$reproduction_rate),
+                          death_rate = as.numeric(cultivars$death_rate),
+                          sigmoid_kappa_host = 0,
+                          sigmoid_sigma_host = 1,
+                          sigmoid_plateau_host = 1,
+                          cultivars_genes_list = cultivars_genes_list
   )
   
   # Evolution parameters
-  genes_param <- list(
-    name = as.character(genes$geneName),
-    fitness_cost = as.numeric(genes$fitness_cost),
-    mutation_prob = as.numeric(genes$mutation_prob),
-    efficiency = as.numeric(genes$efficiency),
-    tradeoff_strength = as.numeric(genes$tradeoff_strength),
-    Nlevels_aggressiveness = as.numeric(genes$Nlevels_aggressiveness),
-    time_to_activ_exp = as.numeric(genes$time_to_activ_exp),
-    time_to_activ_var = as.numeric(genes$time_to_activ_var),
-    target_trait = as.character(genes$target_trait)
+  genes_param <- list(name = as.character(genes$geneName),
+                      fitness_cost = as.numeric(genes$fitness_cost),
+                      mutation_prob = as.numeric(genes$mutation_prob),
+                      efficiency = as.numeric(genes$efficiency),
+                      tradeoff_strength = as.numeric(genes$tradeoff_strength),
+                      Nlevels_aggressiveness = as.numeric(genes$Nlevels_aggressiveness),
+                      time_to_activ_mean = as.numeric(genes$time_to_activ_mean),
+                      time_to_activ_var = as.numeric(genes$time_to_activ_var),
+                      target_trait = as.character(genes$target_trait),
+                      recombination_sd = as.numeric(genes$recombination_sd)
   )
 
   # Economic parameters
-  eco_param <- list(
-    yield_perHa = cbind(
-      H = as.numeric(cultivars$yield_H),
-      L = as.numeric(cultivars$yield_L),
-      I = as.numeric(cultivars$yield_I),
-      R = as.numeric(cultivars$yield_R)
-    ),
-    planting_cost_perHa = as.numeric(cultivars$planting_cost),
-    market_value = as.numeric(cultivars$market_value)
+  eco_param <- list(yield_perHa = cbind(H = as.numeric(cultivars$yield_H),
+                                        L = as.numeric(cultivars$yield_L),
+                                        I = as.numeric(cultivars$yield_I),
+                                        R = as.numeric(cultivars$yield_R)),
+                    planting_cost_perHa = as.numeric(cultivars$planting_cost),
+                    market_value = as.numeric(cultivars$market_value)
   )
 
-
+  
+  basic_patho_param$repro_sex_prob <- repro_sex_prob
+  
   ####
   #### Run the model (C++)
   ####
+  
   print("Run the C++ model")
 
-  dispersal <- list(disp_patho = disp_patho, disp_host = disp_host)
-  inits <- list(pI0 = pI0)
-
   model_landsepi(
     time_param = time_param,
     area_vector = area,
     rotation_matrix = as.matrix(rotation),
     croptypes_cultivars_prop = as.matrix(croptypes_cultivars_prop),
-    dispersal = dispersal,
-    inits = inits,
+    dispersal = list(disp_patho = disp_patho, disp_patho_sex = disp_patho_sex, disp_host = disp_host),
+    inits = list(pI0 = pI0),
     seed = seed,
     cultivars_param = cultivars_param,
     basic_patho_param = basic_patho_param,
-    genes_param = genes_param
+    genes_param = genes_param,
+    treatment_param = treatment
   )
 
 
@@ -313,39 +332,26 @@ simul_landsepi <- function(seed = 12345, time_param = list(Nyears = 20, nTSpY =
   print("Compute model outputs")
   Npoly <- length(area)
 
+  
   ## Evolutionary output
   Npatho <- prod(genes_param$Nlevels_aggressiveness)
   if (Npatho > 1 & evol_outputs[1] != "") {
-    evol_res <- evol_output(evol_outputs, time_param, Npoly, cultivars_param, genes_param,
-      thres_breakdown,
-      writeTXT = writeTXT, graphic = graphic
-    )
+    evol_res <- evol_output(evol_outputs, time_param, Npoly, cultivars_param, genes_param, thres_breakdown, 
+                            writeTXT = writeTXT, graphic = graphic)
   } else {
     evol_res <- NULL
   }
 
   ## Epidemiological output
   if (epid_outputs[1] != "") {
-    ## Limits for graphics
-    ylim_param <- list(
-      audpc = c(0, audpc100S),
-      audpc_rel = c(0, 1),
-      gla = c(0, GLAnoDis),
-      gla_rel = c(0, 1),
-      eco_cost = c(0, NA),
-      eco_yield = c(0, NA),
-      eco_product = c(0, NA),
-      eco_margin = c(NA, NA), 
-      contrib = c(0,1)
-    )
     epid_res <- epid_output(epid_outputs, time_param, Npatho, area, rotation, croptypes_cultivars_prop,
-      cultivars_param, eco_param,
-      GLAnoDis, ylim_param,
-      writeTXT = writeTXT, graphic = graphic
+                            cultivars_param, eco_param, treatment, basic_patho_param, 
+                            audpc100S, writeTXT = writeTXT, graphic = graphic
     )
   } else {
     epid_res <- NULL
   }
+  
 
   ## Video
   if (videoMP4 & !is.null(epid_res[["audpc_rel"]])) {
